---
title: <span class="badge object-type-scalar"></span> NorwegianKrone
---
# <span class="badge object-type-scalar"></span> NorwegianKrone

Currency: Norwegian Krone (kr)

## Definition

```python
# Currency: Norwegian Krone (kr)
NorwegianKrone: typing.Literal["currencyNOK"] = "currencyNOK"
```
